@@ -781,6 +781,7 @@ our %NPPIDM = (
     'IDM_LANG_NNCRONTAB'                                         => ((40000 + 6000) + 76),
     'IDM_LANG_NSIS'                                              => ((40000 + 6000) + 29),
     'IDM_LANG_OBJC'                                              => ((40000 + 6000) + 14),
+    'IDM_LANG_OPENUDLDIR'                                        => ((40000 + 6000) + 300),
     'IDM_LANG_OSCRIPT'                                           => ((40000 + 6000) + 77),
     'IDM_LANG_PASCAL'                                            => ((40000 + 6000) + 11),
     'IDM_LANG_PERL'                                              => ((40000 + 6000) + 13),
@@ -822,7 +823,8 @@ our %NPPIDM = (
     'IDM_MACRO_STARTRECORDINGMACRO'                              => ((40000 + 2000) + 18),
     'IDM_MACRO_STOPRECORDINGMACRO'                               => ((40000 + 2000) + 19),
     'IDM_MISC'                                                   => (40000 + 3500),
-    'IDM_ONLINEHELP'                                             => ((40000  + 7000)  + 3),
+    'IDM_ONLINEDOCUMENT'                                         => ((40000  + 7000)  + 3),     # new name (v7.8 and newer)
+    'IDM_ONLINEHELP'                                             => ((40000  + 7000)  + 3),     # old name (before v7.8)
     'IDM_ONLINESUPPORT'                                          => ((40000  + 7000)  + 11),
     'IDM_OPEN_ALL_RECENT_FILE'                                   => ((40000 + 2000) + 40),
     'IDM_PROJECTPAGE'                                            => ((40000  + 7000)  + 2),
@@ -1000,7 +1002,6 @@ our %NPPIDM = (
     'IDM_VIEW_ZOOMOUT'                                           => ((40000 + 4000) + 24),
     'IDM_VIEW_ZOOMRESTORE'                                       => ((40000 + 4000) + 33),
     'IDM_WIKIFAQ'                                                => ((40000  + 7000)  + 7),
-    'MENUCMDID_H'                                                => '',
 );
 
 =over
